@@ -364,19 +364,18 @@ class Formula(object):
     @property
     def charge(self):
         """
-        Charge of the molecule
+        Net charge of the molecule.
         """
         return sum([m*a.charge for a,m in self.atoms.items()])
 
     @property
     def mass_fraction(self):
         """
-        Mass fraction representation of the elements in the molecule
+        Fractional mass representation of each element/isotope/ion.
         """
         total_mass = self.mass
         return dict((a,m*a.mass/total_mass) for a,m in self.atoms.items())
 
-
     def _pf(self):
         """
         packing factor  | unitless
@@ -653,7 +652,7 @@ def formula_grammar(table):
     implicit_separator = separator | space
     composite << group + ZeroOrMore(implicit_separator + group)
 
-    density = Literal('@').suppress() + count + Optional(Regex("[ni]"),default='n')
+    density = Literal('@').suppress() + count + Optional(Regex("[ni]"),default='i')
     compound = composite + Optional(density,default=None)
     def convert_compound(string,location,tokens):
         #print "compound",tokens
